summaryrefslogtreecommitdiffstats
path: root/src/bookmarkselector.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/bookmarkselector.cpp')
-rw-r--r--src/bookmarkselector.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/bookmarkselector.cpp b/src/bookmarkselector.cpp
index d957140..1e996a1 100644
--- a/src/bookmarkselector.cpp
+++ b/src/bookmarkselector.cpp
@@ -34,8 +34,8 @@
#include "dolphin.h"
#include "urlnavigator.h"
-BookmarkSelector::BookmarkSelector(URLNavigator* tqparent) :
- URLButton(tqparent),
+BookmarkSelector::BookmarkSelector(URLNavigator* parent) :
+ URLButton(parent),
m_selectedIndex(0)
{
setFocusPolicy(TQ_NoFocus);
@@ -88,8 +88,8 @@ void BookmarkSelector::updateSelection(const KURL& url)
int maxLength = 0;
m_selectedIndex = -1;
// Search the bookmark which is equal to the URL or at least is a tqparent URL.
// If there are more than one possible tqparent URL candidates, choose the bookmark
// which covers the bigger range of the URL.
int i = 0;
while (!bookmark.isNull()) {
@@ -136,7 +136,7 @@ void BookmarkSelector::drawButton(TQPainter* painter)
foregroundColor = KGlobalSettings::buttonTextColor();
}
// dimm the colors if the tqparent view does not have the focus
const DolphinView* parentView = urlNavigator()->dolphinView();
const Dolphin& dolphin = Dolphin::mainWin();
@@ -88,8 +88,8 @@ void BookmarkSelector::updateSelection(const KURL& url)
int maxLength = 0;
m_selectedIndex = -1;
- // Search the bookmark which is equal to the URL or at least is a tqparent URL.
- // If there are more than one possible tqparent URL candidates, choose the bookmark
+ // Search the bookmark which is equal to the URL or at least is a parent URL.
+ // If there are more than one possible parent URL candidates, choose the bookmark
// which covers the bigger range of the URL.
int i = 0;
@@ -136,7 +136,7 @@ void BookmarkSelector::drawButton(TQPainter* painter)
foregroundColor = KGlobalSettings::buttonTextColor();
}
- // dimm the colors if the tqparent view does not have the focus
+ // dimm the colors if the parent view does not have the focus
const DolphinView* parentView = urlNavigator()->dolphinView();
const Dolphin& dolphin = Dolphin::mainWin();